/**
 * \file        lzma/index.h
 * \brief       Handling of Index lists
 *
 * \author      Copyright (C) 1999-2006 Igor Pavlov
 * \author      Copyright (C) 2007 Lasse Collin
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 */

#ifndef LZMAALPHA_H_INTERNAL
#	error Never include this file directly. Use <lzma.h> instead.
#endif


/**
 * \brief
 *
 * FIXME desc
 */
typedef struct lzmaalpha_index_s lzmaalpha_index;
struct lzmaalpha_index_s {
	/**
	 * \brief       Total Size of the Block
	 *
	 * This includes Block Header, Compressed Data, and Block Footer.
	 */
	lzmaalpha_vli total_size;

	/**
	 * \brief       Uncompressed Size of the Block
	 */
	lzmaalpha_vli uncompressed_size;

	/**
	 * \brief       Pointer to the next Index Record
	 *
	 * This is NULL on the last Index Record.
	 */
	lzmaalpha_index *next;
};


/**
 * \brief       Duplicates an Index list
 *
 * \return      A copy of the Index list, or NULL if memory allocation
 *              failed or the original Index was empty.
 */
extern lzmaalpha_index *lzmaalpha_index_dup(
		const lzmaalpha_index *index, lzmaalpha_allocator *allocator);


/**
 * \brief       Frees an Index list
 *
 * All Index Recors in the list are freed. This function is convenient when
 * getting rid of lzmaalpha_metadata structures containing an Index.
 */
extern void lzmaalpha_index_free(lzmaalpha_index *index, lzmaalpha_allocator *allocator);


/**
 * \brief       Calculates information about the Index
 *
 * \return      LZMAALPHA_OK on success, LZMAALPHA_PROG_ERROR on error. FIXME
 */
extern lzmaalpha_ret lzmaalpha_index_count(const lzmaalpha_index *index, size_t *count,
		lzmaalpha_vli *lzmaalpha_restrict total_size,
		lzmaalpha_vli *lzmaalpha_restrict uncompressed_size);


/**
 * \brief       Compares if two Index lists are identical
 */
extern lzmaalpha_bool lzmaalpha_index_is_equal(const lzmaalpha_index *a, const lzmaalpha_index *b);
